@@ -1,5 +1,5 @@
 # encoding: utf-8
-
+import json
 # Nagstamon - Nagios status monitor for your desktop
 # Copyright (C) 2008-2024 Henri Wahl <henri@nagstamon.de> et al.
 #
@@ -25,6 +25,8 @@ import urllib.request, urllib.parse, urllib.error
 import time
 import copy
 import html
+from datetime import datetime
+from zoneinfo import ZoneInfo
 
 from Nagstamon.Objects import (GenericHost,
                                GenericService,
@@ -103,6 +105,10 @@ class MultisiteServer(GenericServer):
               'api_svcprob_act': self.monitor_url + '/view.py?_transid=-1&_do_actions=yes&_do_confirm=Yes!&view_name=svcproblems&filled_in=actions&lang=',
               'human_events':    self.monitor_url + '/index.py?%s' %
                                                    urllib.parse.urlencode({'start_url': 'view.py?view_name=events'}),
+              'omd_host_downtime': self.monitor_url + '/api/1.0/domain-types/downtime/collections/host',
+              'omd_svc_downtime': self.monitor_url + '/api/1.0/domain-types/downtime/collections/service',
+              'recheck':         self.monitor_url + '/ajax_reschedule.py?_ajaxid=0',
+              'omd_version':         self.monitor_url + '/api/1.0/version',
               'transid':         self.monitor_url + '/view.py?actions=yes&filled_in=actions&host=$HOST$&service=$SERVICE$&view_name=service'
             }
 
@@ -114,6 +120,12 @@ class MultisiteServer(GenericServer):
                 'PEND':    'PENDING',
             }
 
+        # Function overrides for Checkmk 2.3+
+        version = self._omd_get_version()
+        if version >= [2, 3]:
+            self._set_downtime = self._omd_set_downtime
+            self._set_recheck = self._omd_set_recheck
+
         if self.CookieAuth and not self.refresh_authentication:
             # get cookie to access Checkmk web interface
             if 'cookies' in dir(self.session):
@@ -149,7 +161,7 @@ class MultisiteServer(GenericServer):
         return False
 
     def _get_url(self, url):
-        result = self.FetchURL(url, 'raw')
+        result = self.fetch_url(url, 'raw')
         content, error, status_code = result.result, result.error, result.status_code
 
         if error != '' or status_code >= 400:
@@ -161,7 +173,7 @@ class MultisiteServer(GenericServer):
             c = content.split('\n')
 
             # Print non ERRORS to the log in debug mode
-            self.Debug(server=self.get_name(), debug=c[0])
+            self.debug(server=self.get_name(), debug=c[0])
 
             raise MultisiteError(False, Result(result='\n'.join(c[1:]),
                                                error=c[0],
@@ -185,7 +197,7 @@ class MultisiteServer(GenericServer):
             # if first attempt login and then try to get data again
             if not self._is_auth_in_cookies():
                 self._get_cookie_login()
-                result = self.FetchURL(url, 'raw')
+                result = self.fetch_url(url, 'raw')
                 content, error = result.result, result.error
                 if content.startswith('<') or\
                 '<!DOCTYPE html>' in content:
@@ -212,9 +224,9 @@ class MultisiteServer(GenericServer):
         # get cookie from login page via url retrieving as with other urls
         try:
             # login and get cookie
-            self.FetchURL(self.monitor_url + '/login.py', cgi_data=login_data, multipart=True)
+            self.fetch_url(self.monitor_url + '/login.py', cgi_data=login_data, multipart=True)
         except:
-            self.Error(sys.exc_info())
+            self.error(sys.exc_info())
 
 
     def _get_status(self):
@@ -300,7 +312,7 @@ class MultisiteServer(GenericServer):
             traceback.print_exc(file=sys.stdout)
 
             self.isChecking = False
-            result, error = self.Error(sys.exc_info())
+            result, error = self.error(sys.exc_info())
             return Result(result=result, error=error)
 
         # Add filters to the url which should only be applied to the service request
@@ -363,7 +375,7 @@ class MultisiteServer(GenericServer):
                     self.new_hosts[n['host']].services[new_service].address = n['address']
                     self.new_hosts[n['host']].services[new_service].command = n['command']
 
-                    # transistion to Checkmk 1.1.10p2
+                    # transition to Checkmk 1.1.10p2
                     if 'svc_in_downtime' in service:
                         if service['svc_in_downtime'] == 'yes':
                             self.new_hosts[n['host']].services[new_service].scheduled_downtime = True
@@ -376,6 +388,9 @@ class MultisiteServer(GenericServer):
                     if 'svc_notifications_enabled' in service:
                         if service['svc_notifications_enabled'] == 'no':
                             self.new_hosts[n['host']].services[new_service].notifications_disabled = True
+                    if 'host_in_downtime' in service:
+                        if service['host_in_downtime'] == 'yes':
+                            self.new_hosts[n['host']].scheduled_downtime = True
 
                     # hard/soft state for later filter evaluation
                     real_attempt, max_attempt = self.new_hosts[n['host']].services[new_service].attempt.split('/')
@@ -392,7 +407,7 @@ class MultisiteServer(GenericServer):
 
             # set checking flag back to False
             self.isChecking = False
-            result, error = self.Error(sys.exc_info())
+            result, error = self.error(sys.exc_info())
             return Result(result=copy.deepcopy(result), error=copy.deepcopy(error))
 
         del url_params
@@ -411,11 +426,11 @@ class MultisiteServer(GenericServer):
             url = self.urls['human_service'] + urllib.parse.urlencode({'x': 'site='+self.hosts[host].site+'&host='+host+'&service='+service}).replace('x=', '%26')
 
         if conf.debug_mode:
-            self.Debug(server=self.get_name(), host=host, service=service, debug='Open host/service monitor web page ' + url)
+            self.debug(server=self.get_name(), host=host, service=service, debug='Open host/service monitor web page ' + url)
         webbrowser_open(url)
 
 
-    def GetHost(self, host):
+    def get_host(self, host):
         """
             find out ip or hostname of given host to access hosts/devices which do not appear in DNS but
             have their ip saved in Nagios
@@ -432,7 +447,7 @@ class MultisiteServer(GenericServer):
                 ip = self.hosts[host].address
 
             if conf.debug_mode:
-                self.Debug(server=self.get_name(), host=host, debug ='IP of %s:' % (host) + ' ' + ip)
+                self.debug(server=self.get_name(), host=host, debug ='IP of %s:' % (host) + ' ' + ip)
 
             if conf.connect_by_dns:
                 try:
@@ -442,7 +457,7 @@ class MultisiteServer(GenericServer):
             else:
                 address = ip
         except:
-            result, error = self.Error(sys.exc_info())
+            result, error = self.error(sys.exc_info())
             return Result(result=result, error=error)
 
         return Result(result=address)
@@ -473,10 +488,10 @@ class MultisiteServer(GenericServer):
         url = url.replace('?_transid=-1&', '?_transid=%s&' % (transid))
 
         if conf.debug_mode:
-            self.Debug(server=self.get_name(), host=host, debug ='Submitting action: ' + url + '&' + urllib.parse.urlencode(params))
+            self.debug(server=self.get_name(), host=host, debug ='Submitting action: ' + url + '&' + urllib.parse.urlencode(params))
 
         # apply action
-        self.FetchURL(url + '&' + urllib.parse.urlencode(params))
+        self.fetch_url(url + '&' + urllib.parse.urlencode(params))
 
 
     def _set_downtime(self, host, service, author, comment, fixed, start_time, end_time, hours, minutes):
@@ -519,7 +534,47 @@ class MultisiteServer(GenericServer):
             self._action(self.hosts[host].site, host, service, params)
         except:
             if conf.debug_mode:
-                self.Debug(server=self.get_name(), host=host,
+                self.debug(server=self.get_name(), host=host,
+                           debug='Invalid start/end date/time given')
+
+
+    def _omd_set_downtime(self, host, service, author, comment, fixed, start_time, end_time, hours, minutes):
+        """
+           _set_downtime function for Checkmk version 2.3+
+        """
+        try:
+            # Headers required for Checkmk API
+            headers = {
+                "Authorization": f"Bearer {self.username} {self.password}",
+                "Content-Type": "application/json",
+                "Accept": "application/json",
+            }
+
+            # Only timezone aware dates are allowed
+            iso_start_time =  datetime.strptime(start_time, "%Y-%m-%d %H:%M").replace(tzinfo=ZoneInfo('localtime')).isoformat()
+            iso_end_time =  datetime.strptime(end_time, "%Y-%m-%d %H:%M").replace(tzinfo=ZoneInfo('localtime')).isoformat()
+            # Set parameters for host downtimes
+            url = self.urls["omd_host_downtime"]
+            params = {
+                "start_time": iso_start_time,
+                "end_time": iso_end_time,
+                "comment": author == self.username and comment or "%s: %s" % (author, comment),
+                "downtime_type": "host",
+                "host_name": host,
+            }
+
+            # Downtime type is "flexible" if "duration" is set
+            if fixed == 0:
+                params['duration'] = hours * 60 + minutes
+            # Parameter overrides for service downtimes
+            if service:
+                url = self.urls['omd_svc_downtime']
+                params['downtime_type'] = 'service'
+                params['service_descriptions'] = [service]
+            self.fetch_url(url, headers=headers, cgi_data=json.dumps(params))
+        except Exception as error:
+            if conf.debug_mode:
+                self.debug(server=self.get_name(), host=host,
                            debug='Invalid start/end date/time given')
 
 
@@ -547,6 +602,21 @@ class MultisiteServer(GenericServer):
         self._action(self.hosts[host].site, host, service, p)
 
 
+    def _omd_set_recheck(self, host, service):
+        """
+           _set_recheck function for Checkmk version 2.3+
+        """
+        csrf_token = self._get_csrf_token(host, service)
+        data = {
+            "site": self.hosts[host].site,
+            "host": host,
+            "service": service,
+            "wait_svc": service,
+            "csrf_token": csrf_token,
+        }
+        self.fetch_url(self.urls["recheck"], cgi_data=data)
+
+
     def recheck_all(self):
         """
             special method for Checkmk as there is one URL for rescheduling all problems to be checked
@@ -556,9 +626,9 @@ class MultisiteServer(GenericServer):
         url = self.urls['api_svcprob_act']
 
         if conf.debug_mode:
-            self.Debug(server=self.get_name(), debug ='Rechecking all action: ' + url + '&' + urllib.parse.urlencode(params))
+            self.debug(server=self.get_name(), debug ='Rechecking all action: ' + url + '&' + urllib.parse.urlencode(params))
 
-        result = self.FetchURL(url + '&' + urllib.parse.urlencode(params), giveback = 'raw')
+        result = self.fetch_url(url + '&' + urllib.parse.urlencode(params), giveback ='raw')
 
 
     def _get_transid(self, host, service):
@@ -568,6 +638,29 @@ class MultisiteServer(GenericServer):
         # since Checkmk 2.0 it seems to be a problem if service is empty so fill it with a definitively existing one
         if not service:
             service = 'PING'
-        transid = self.FetchURL(self.urls['transid'].replace('$HOST$', host).replace('$SERVICE$', service.replace(' ', '+')),
+        transid = self.fetch_url(self.urls['transid'].replace('$HOST$', host).replace('$SERVICE$', service.replace(' ', '+')),
                                 'obj').result.find(attrs={'name' : '_transid'})['value']
         return transid
+
+
+    def _get_csrf_token(self, host, service):
+        """
+           get csrf token for the session
+        """
+        # since Checkmk 2.0 it seems to be a problem if service is empty so fill it with a definitively existing one
+        if not service:
+            service = "PING"
+        csrf_token = self.fetch_url(self.urls["transid"].replace("$HOST$", host).replace("$SERVICE$", service.replace(" ", "+")), "obj").result.find(attrs={"name": "csrf_token"})["value"]
+        return csrf_token
+
+
+    def _omd_get_version(self):
+        """
+           get version of OMD Checkmk as [major_version, minor_version]
+        """
+        try:
+            version = [int(x) for x in self.fetch_url(self.urls['omd_version'], 'json').result['versions']['checkmk'].split('.')[:2]]
+        # If /version api is not supported, return the lowest non-negative pair
+        except:
+            version = [0, 0]
+        return version
